@@ -637,7 +637,8 @@ def update_app_utils(appname, branch, keys=False, reboot=False):
     CONFIG_DIR = "config/"
     ENV_DIR = "environments/"
     KEY_DIR = ("keys/" + ENVIRONMENT) if (keys in TRUTH_VALUES) else ""
-    DIRS_TO_TAR = CONFIG_DIR + " " + ENV_DIR + " " + KEY_DIR
+    CERTS_DIR = "certs/"
+    DIRS_TO_TAR = CONFIG_DIR + " " + ENV_DIR + " " + KEY_DIR + CERTS_DIR
 
     # If it's a shared utils repo, need to reach down into this app's directory
     if os.path.isdir(APP_UTILS_DIR):
